# SUMOnet

> SUMOnet is a python library to predict SUMOylation sites by using a unique deep learning architecture.

> We will update that README.md as soon as results are published.

## Requirements

> We strongly recomment using virtual environment for these package requirements.

> All packages will be installed automatically by pip.

```python
python 3.6.6
numpy 1.19.5
scikit-learn 0.24.2
joblib 1.0.0
pandas 1.0.5
epitopepredict 0.5.0
tensorflow 2.4.0
keras 2.3.1
```

## Installation

You can simply install SUMOnet by using pip

```python
pip install sumonet==0.0.2
```

Versions can be followed by [pypi](https://pypi.org/project/sumonet/)

## Usage

> We will release a website for usage

## Author

> Coding: Berke Dilekoglu

> Paper and Experiments: Oznur Tastan, Berke Dilekoglu

## License

[Academic Free License ("AFL") v. 3.0](https://choosealicense.com/licenses/afl-3.0/#)
